@@ -1,4 +1,4 @@
-__version__ = '1.0.20'
+__version__ = '1.0.21'
 __author__ = 'arnold'
 
 import json
@@ -7,6 +7,7 @@ import os
 import requests
 from urllib.parse import urljoin
 import posixpath
+import sys
 
 from jinja2 import nodes
 from jinja2.ext import Extension
@@ -117,5 +118,4 @@ class TerraformQueryExtension(Extension):
                 if(value_name is not None):
                     return output["attributes"]["value"][value_name]
                 else:
-                    print("Value is None")
-                    exit()
+                    sys.exit("Value is None") 
